==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/rds/kotlin/SnapshotCopy.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.rds.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Deprecated
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [SnapshotCopy].
 */
@PulumiTagMarker
public class SnapshotCopyResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: SnapshotCopyArgs = SnapshotCopyArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend SnapshotCopyArgsBuilder.() -> Unit) {
        val builder = SnapshotCopyArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): SnapshotCopy {
        val builtJavaResource = com.pulumi.aws.rds.SnapshotCopy(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return SnapshotCopy(builtJavaResource)
    }
}

/**
 * Manages an RDS database instance snapshot copy. For managing RDS database cluster snapshots, see the `aws.rds.ClusterSnapshot` resource.
 * ## Example Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.rds.Instance;
 * import com.pulumi.aws.rds.InstanceArgs;
 * import com.pulumi.aws.rds.Snapshot;
 * import com.pulumi.aws.rds.SnapshotArgs;
 * import com.pulumi.aws.rds.SnapshotCopy;
 * import com.pulumi.aws.rds.SnapshotCopyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var exampleInstance = new Instance("exampleInstance", InstanceArgs.builder()
 *             .allocatedStorage(10)
 *             .engine("mysql")
 *             .engineVersion("5.6.21")
 *             .instanceClass("db.t2.micro")
 *             .dbName("baz")
 *             .password("barbarbarbar")
 *             .username("foo")
 *             .maintenanceWindow("Fri:09:00-Fri:09:30")
 *             .backupRetentionPeriod(0)
 *             .parameterGroupName("default.mysql5.6")
 *             .build());
 *         var exampleSnapshot = new Snapshot("exampleSnapshot", SnapshotArgs.builder()
 *             .dbInstanceIdentifier(exampleInstance.identifier())
 *             .dbSnapshotIdentifier("testsnapshot1234")
 *             .build());
 *         var exampleSnapshotCopy = new SnapshotCopy("exampleSnapshotCopy", SnapshotCopyArgs.builder()
 *             .sourceDbSnapshotIdentifier(exampleSnapshot.dbSnapshotArn())
 *             .targetDbSnapshotIdentifier("testsnapshot1234-copy")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * Using `pulumi import`, import `aws_db_snapshot_copy` using the snapshot identifier. For example:
 * ```sh
 *  $ pulumi import aws:rds/snapshotCopy:SnapshotCopy example my-snapshot
 * ```
 *
 */
public class SnapshotCopy internal constructor(
    override val javaResource: com.pulumi.aws.rds.SnapshotCopy,
) : KotlinCustomResource(javaResource, SnapshotCopyMapper) {
    /**
     * Specifies the allocated storage size in gigabytes (GB).
     */
    public val allocatedStorage: Output<Int>
        get() = javaResource.allocatedStorage().applyValue({ args0 -> args0 })

    /**
     * Specifies the name of the Availability Zone the DB instance was located in at the time of the DB snapshot.
     */
    public val availabilityZone: Output<String>
        get() = javaResource.availabilityZone().applyValue({ args0 -> args0 })

    /**
     * Whether to copy existing tags. Defaults to `false`.
     */
    public val copyTags: Output<Boolean>?
        get() = javaResource.copyTags().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The Amazon Resource Name (ARN) for the DB snapshot.
     */
    public val dbSnapshotArn: Output<String>
        get() = javaResource.dbSnapshotArn().applyValue({ args0 -> args0 })

    /**
     * The Destination region to place snapshot copy.
     */
    public val destinationRegion: Output<String>?
        get() = javaResource.destinationRegion().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies whether the DB snapshot is encrypted.
     */
    public val encrypted: Output<Boolean>
        get() = javaResource.encrypted().applyValue({ args0 -> args0 })

    /**
     * Specifies the name of the database engine.
     */
    public val engine: Output<String>
        get() = javaResource.engine().applyValue({ args0 -> args0 })

    /**
     * Specifies the version of the database engine.
     */
    public val engineVersion: Output<String>
        get() = javaResource.engineVersion().applyValue({ args0 -> args0 })

    /**
     * Specifies the Provisioned IOPS (I/O operations per second) value of the DB instance at the time of the snapshot.
     */
    public val iops: Output<Int>
        get() = javaResource.iops().applyValue({ args0 -> args0 })

    /**
     * KMS key ID.
     */
    public val kmsKeyId: Output<String>?
        get() = javaResource.kmsKeyId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * License model information for the restored DB instance.
     */
    public val licenseModel: Output<String>
        get() = javaResource.licenseModel().applyValue({ args0 -> args0 })

    /**
     * The name of an option group to associate with the copy of the snapshot.
     */
    public val optionGroupName: Output<String>
        get() = javaResource.optionGroupName().applyValue({ args0 -> args0 })

    public val port: Output<Int>
        get() = javaResource.port().applyValue({ args0 -> args0 })

    /**
     * he URL that contains a Signature Version 4 signed request.
     */
    public val presignedUrl: Output<String>?
        get() = javaResource.presignedUrl().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val snapshotType: Output<String>
        get() = javaResource.snapshotType().applyValue({ args0 -> args0 })

    /**
     * Snapshot identifier of the source snapshot.
     */
    public val sourceDbSnapshotIdentifier: Output<String>
        get() = javaResource.sourceDbSnapshotIdentifier().applyValue({ args0 -> args0 })

    /**
     * The region that the DB snapshot was created in or copied from.
     */
    public val sourceRegion: Output<String>
        get() = javaResource.sourceRegion().applyValue({ args0 -> args0 })

    /**
     * Specifies the storage type associated with DB snapshot.
     */
    public val storageType: Output<String>
        get() = javaResource.storageType().applyValue({ args0 -> args0 })

    /**
     * Key-value map of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
     */
    @Deprecated(
        message = """
  Please use `tags` instead.
  """,
    )
    public val tagsAll: Output<Map<String, String>>
        get() = javaResource.tagsAll().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.key.to(args0.value)
            }).toMap()
        })

    /**
     * The external custom Availability Zone.
     */
    public val targetCustomAvailabilityZone: Output<String>?
        get() = javaResource.targetCustomAvailabilityZone().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The Identifier for the snapshot.
     */
    public val targetDbSnapshotIdentifier: Output<String>
        get() = javaResource.targetDbSnapshotIdentifier().applyValue({ args0 -> args0 })

    /**
     * Provides the VPC ID associated with the DB snapshot.
     */
    public val vpcId: Output<String>
        get() = javaResource.vpcId().applyValue({ args0 -> args0 })
}

public object SnapshotCopyMapper : ResourceMapper<SnapshotCopy> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.rds.SnapshotCopy::class == javaResource::class

    override fun map(javaResource: Resource): SnapshotCopy = SnapshotCopy(
        javaResource as
            com.pulumi.aws.rds.SnapshotCopy,
    )
}

/**
 * @see [SnapshotCopy].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [SnapshotCopy].
 */
public suspend fun snapshotCopy(
    name: String,
    block: suspend SnapshotCopyResourceBuilder.() -> Unit,
): SnapshotCopy {
    val builder = SnapshotCopyResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [SnapshotCopy].
 * @param name The _unique_ name of the resulting resource.
 */
public fun snapshotCopy(name: String): SnapshotCopy {
    val builder = SnapshotCopyResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/rds/kotlin/SnapshotCopy.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.rds.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Deprecated
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Builder for [SnapshotCopy].
 */
@PulumiTagMarker
public class SnapshotCopyResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: SnapshotCopyArgs = SnapshotCopyArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend SnapshotCopyArgsBuilder.() -> Unit) {
        val builder = SnapshotCopyArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): SnapshotCopy {
        val builtJavaResource = com.pulumi.aws.rds.SnapshotCopy(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return SnapshotCopy(builtJavaResource)
    }
}

/**
 * Manages an RDS database instance snapshot copy. For managing RDS database cluster snapshots, see the `aws.rds.ClusterSnapshot` resource.
 * ## Example Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.rds.Instance("example", {
 *     allocatedStorage: 10,
 *     engine: "mysql",
 *     engineVersion: "5.6.21",
 *     instanceClass: aws.rds.InstanceType.T2_Micro,
 *     dbName: "baz",
 *     password: "barbarbarbar",
 *     username: "foo",
 *     maintenanceWindow: "Fri:09:00-Fri:09:30",
 *     backupRetentionPeriod: 0,
 *     parameterGroupName: "default.mysql5.6",
 * });
 * const exampleSnapshot = new aws.rds.Snapshot("example", {
 *     dbInstanceIdentifier: example.identifier,
 *     dbSnapshotIdentifier: "testsnapshot1234",
 * });
 * const exampleSnapshotCopy = new aws.rds.SnapshotCopy("example", {
 *     sourceDbSnapshotIdentifier: exampleSnapshot.dbSnapshotArn,
 *     targetDbSnapshotIdentifier: "testsnapshot1234-copy",
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.rds.Instance("example",
 *     allocated_storage=10,
 *     engine="mysql",
 *     engine_version="5.6.21",
 *     instance_class=aws.rds.InstanceType.T2_MICRO,
 *     db_name="baz",
 *     password="barbarbarbar",
 *     username="foo",
 *     maintenance_window="Fri:09:00-Fri:09:30",
 *     backup_retention_period=0,
 *     parameter_group_name="default.mysql5.6")
 * example_snapshot = aws.rds.Snapshot("example",
 *     db_instance_identifier=example.identifier,
 *     db_snapshot_identifier="testsnapshot1234")
 * example_snapshot_copy = aws.rds.SnapshotCopy("example",
 *     source_db_snapshot_identifier=example_snapshot.db_snapshot_arn,
 *     target_db_snapshot_identifier="testsnapshot1234-copy")
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.Rds.Instance("example", new()
 *     {
 *         AllocatedStorage = 10,
 *         Engine = "mysql",
 *         EngineVersion = "5.6.21",
 *         InstanceClass = Aws.Rds.InstanceType.T2_Micro,
 *         DbName = "baz",
 *         Password = "barbarbarbar",
 *         Username = "foo",
 *         MaintenanceWindow = "Fri:09:00-Fri:09:30",
 *         BackupRetentionPeriod = 0,
 *         ParameterGroupName = "default.mysql5.6",
 *     });
 *     var exampleSnapshot = new Aws.Rds.Snapshot("example", new()
 *     {
 *         DbInstanceIdentifier = example.Identifier,
 *         DbSnapshotIdentifier = "testsnapshot1234",
 *     });
 *     var exampleSnapshotCopy = new Aws.Rds.SnapshotCopy("example", new()
 *     {
 *         SourceDbSnapshotIdentifier = exampleSnapshot.DbSnapshotArn,
 *         TargetDbSnapshotIdentifier = "testsnapshot1234-copy",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/rds"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		example, err := rds.NewInstance(ctx, "example", &rds.InstanceArgs{
 * 			AllocatedStorage:      pulumi.Int(10),
 * 			Engine:                pulumi.String("mysql"),
 * 			EngineVersion:         pulumi.String("5.6.21"),
 * 			InstanceClass:         pulumi.String(rds.InstanceType_T2_Micro),
 * 			DbName:                pulumi.String("baz"),
 * 			Password:              pulumi.String("barbarbarbar"),
 * 			Username:              pulumi.String("foo"),
 * 			MaintenanceWindow:     pulumi.String("Fri:09:00-Fri:09:30"),
 * 			BackupRetentionPeriod: pulumi.Int(0),
 * 			ParameterGroupName:    pulumi.String("default.mysql5.6"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		exampleSnapshot, err := rds.NewSnapshot(ctx, "example", &rds.SnapshotArgs{
 * 			DbInstanceIdentifier: example.Identifier,
 * 			DbSnapshotIdentifier: pulumi.String("testsnapshot1234"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		_, err = rds.NewSnapshotCopy(ctx, "example", &rds.SnapshotCopyArgs{
 * 			SourceDbSnapshotIdentifier: exampleSnapshot.DbSnapshotArn,
 * 			TargetDbSnapshotIdentifier: pulumi.String("testsnapshot1234-copy"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.rds.Instance;
 * import com.pulumi.aws.rds.InstanceArgs;
 * import com.pulumi.aws.rds.Snapshot;
 * import com.pulumi.aws.rds.SnapshotArgs;
 * import com.pulumi.aws.rds.SnapshotCopy;
 * import com.pulumi.aws.rds.SnapshotCopyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new Instance("example", InstanceArgs.builder()
 *             .allocatedStorage(10)
 *             .engine("mysql")
 *             .engineVersion("5.6.21")
 *             .instanceClass("db.t2.micro")
 *             .dbName("baz")
 *             .password("barbarbarbar")
 *             .username("foo")
 *             .maintenanceWindow("Fri:09:00-Fri:09:30")
 *             .backupRetentionPeriod(0)
 *             .parameterGroupName("default.mysql5.6")
 *             .build());
 *         var exampleSnapshot = new Snapshot("exampleSnapshot", SnapshotArgs.builder()
 *             .dbInstanceIdentifier(example.identifier())
 *             .dbSnapshotIdentifier("testsnapshot1234")
 *             .build());
 *         var exampleSnapshotCopy = new SnapshotCopy("exampleSnapshotCopy", SnapshotCopyArgs.builder()
 *             .sourceDbSnapshotIdentifier(exampleSnapshot.dbSnapshotArn())
 *             .targetDbSnapshotIdentifier("testsnapshot1234-copy")
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:rds:Instance
 *     properties:
 *       allocatedStorage: 10
 *       engine: mysql
 *       engineVersion: 5.6.21
 *       instanceClass: db.t2.micro
 *       dbName: baz
 *       password: barbarbarbar
 *       username: foo
 *       maintenanceWindow: Fri:09:00-Fri:09:30
 *       backupRetentionPeriod: 0
 *       parameterGroupName: default.mysql5.6
 *   exampleSnapshot:
 *     type: aws:rds:Snapshot
 *     name: example
 *     properties:
 *       dbInstanceIdentifier: ${example.identifier}
 *       dbSnapshotIdentifier: testsnapshot1234
 *   exampleSnapshotCopy:
 *     type: aws:rds:SnapshotCopy
 *     name: example
 *     properties:
 *       sourceDbSnapshotIdentifier: ${exampleSnapshot.dbSnapshotArn}
 *       targetDbSnapshotIdentifier: testsnapshot1234-copy
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Import
 * Using `pulumi import`, import `aws_db_snapshot_copy` using the snapshot identifier. For example:
 * ```sh
 * $ pulumi import aws:rds/snapshotCopy:SnapshotCopy example my-snapshot
 * ```
 */
public class SnapshotCopy internal constructor(
    override val javaResource: com.pulumi.aws.rds.SnapshotCopy,
) : KotlinCustomResource(javaResource, SnapshotCopyMapper) {
    /**
     * Specifies the allocated storage size in gigabytes (GB).
     */
    public val allocatedStorage: Output<Int>
        get() = javaResource.allocatedStorage().applyValue({ args0 -> args0 })

    /**
     * Specifies the name of the Availability Zone the DB instance was located in at the time of the DB snapshot.
     */
    public val availabilityZone: Output<String>
        get() = javaResource.availabilityZone().applyValue({ args0 -> args0 })

    /**
     * Whether to copy existing tags. Defaults to `false`.
     */
    public val copyTags: Output<Boolean>?
        get() = javaResource.copyTags().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The Amazon Resource Name (ARN) for the DB snapshot.
     */
    public val dbSnapshotArn: Output<String>
        get() = javaResource.dbSnapshotArn().applyValue({ args0 -> args0 })

    /**
     * The Destination region to place snapshot copy.
     */
    public val destinationRegion: Output<String>?
        get() = javaResource.destinationRegion().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Specifies whether the DB snapshot is encrypted.
     */
    public val encrypted: Output<Boolean>
        get() = javaResource.encrypted().applyValue({ args0 -> args0 })

    /**
     * Specifies the name of the database engine.
     */
    public val engine: Output<String>
        get() = javaResource.engine().applyValue({ args0 -> args0 })

    /**
     * Specifies the version of the database engine.
     */
    public val engineVersion: Output<String>
        get() = javaResource.engineVersion().applyValue({ args0 -> args0 })

    /**
     * Specifies the Provisioned IOPS (I/O operations per second) value of the DB instance at the time of the snapshot.
     */
    public val iops: Output<Int>
        get() = javaResource.iops().applyValue({ args0 -> args0 })

    /**
     * KMS key ID.
     */
    public val kmsKeyId: Output<String>?
        get() = javaResource.kmsKeyId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * License model information for the restored DB instance.
     */
    public val licenseModel: Output<String>
        get() = javaResource.licenseModel().applyValue({ args0 -> args0 })

    /**
     * The name of an option group to associate with the copy of the snapshot.
     */
    public val optionGroupName: Output<String>
        get() = javaResource.optionGroupName().applyValue({ args0 -> args0 })

    public val port: Output<Int>
        get() = javaResource.port().applyValue({ args0 -> args0 })

    /**
     * he URL that contains a Signature Version 4 signed request.
     */
    public val presignedUrl: Output<String>?
        get() = javaResource.presignedUrl().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * (Optional) List of AWS Account ids to share snapshot with, use `all` to make snaphot public.
     */
    public val sharedAccounts: Output<List<String>>?
        get() = javaResource.sharedAccounts().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    public val snapshotType: Output<String>
        get() = javaResource.snapshotType().applyValue({ args0 -> args0 })

    /**
     * Snapshot identifier of the source snapshot.
     */
    public val sourceDbSnapshotIdentifier: Output<String>
        get() = javaResource.sourceDbSnapshotIdentifier().applyValue({ args0 -> args0 })

    /**
     * The region that the DB snapshot was created in or copied from.
     */
    public val sourceRegion: Output<String>
        get() = javaResource.sourceRegion().applyValue({ args0 -> args0 })

    /**
     * Specifies the storage type associated with DB snapshot.
     */
    public val storageType: Output<String>
        get() = javaResource.storageType().applyValue({ args0 -> args0 })

    /**
     * Key-value map of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
     */
    @Deprecated(
        message = """
  Please use `tags` instead.
  """,
    )
    public val tagsAll: Output<Map<String, String>>
        get() = javaResource.tagsAll().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.key.to(args0.value)
            }).toMap()
        })

    /**
     * The external custom Availability Zone.
     */
    public val targetCustomAvailabilityZone: Output<String>?
        get() = javaResource.targetCustomAvailabilityZone().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The Identifier for the snapshot.
     */
    public val targetDbSnapshotIdentifier: Output<String>
        get() = javaResource.targetDbSnapshotIdentifier().applyValue({ args0 -> args0 })

    /**
     * Provides the VPC ID associated with the DB snapshot.
     */
    public val vpcId: Output<String>
        get() = javaResource.vpcId().applyValue({ args0 -> args0 })
}

public object SnapshotCopyMapper : ResourceMapper<SnapshotCopy> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.rds.SnapshotCopy::class == javaResource::class

    override fun map(javaResource: Resource): SnapshotCopy = SnapshotCopy(
        javaResource as
            com.pulumi.aws.rds.SnapshotCopy,
    )
}

/**
 * @see [SnapshotCopy].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [SnapshotCopy].
 */
public suspend fun snapshotCopy(
    name: String,
    block: suspend SnapshotCopyResourceBuilder.() -> Unit,
): SnapshotCopy {
    val builder = SnapshotCopyResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [SnapshotCopy].
 * @param name The _unique_ name of the resulting resource.
 */
public fun snapshotCopy(name: String): SnapshotCopy {
    val builder = SnapshotCopyResourceBuilder()
    builder.name(name)
    return builder.build()
}
